@@ -46,6 +46,7 @@ class Args(object):
         self.resume: bool = None
         self.no_check: bool = None
         self.keep: bool = None
+        self.force: bool = None
 
         # Vmaf
         self.vmaf: bool = None
@@ -60,6 +61,7 @@ class Args(object):
         self.vmaf_plots: bool = None
         self.vmaf_rate: int = None
         self.n_threads: int = None
+        self.vmaf_filter: str = None
 
         # VVC
         self.vvc_conf: Path = None
@@ -71,6 +73,9 @@ class Args(object):
         # Inner
         self.counter = None
 
+        # Vapoursynth
+        self.is_vs: bool = None
+
 
 def arg_parsing():
     """Command line parsing"""
@@ -86,11 +91,12 @@ def arg_parsing():
     io_group.add_argument('--logging', '-log', type=str, default=None, help='Enable logging')
     io_group.add_argument('--resume', '-r', help='Resuming previous session', action='store_true')
     io_group.add_argument('--keep', help='Keep temporally folder after encode', action='store_true')
+    io_group.add_argument('--force', help="Force encoding if input args seen as invalid", action='store_true')
 
     # Splitting
     split_group = parser.add_argument_group('Splitting')
     split_group.add_argument('--chunk_method', '-cm', type=str, default='hybrid', help='Method for creating chunks',
-                             choices=['select', 'vs_ffms2', 'hybrid'])
+                             choices=['select', 'vs_ffms2', 'vs_lsmash', 'hybrid'])
     split_group.add_argument('--scenes', '-s', type=str, default=None, help='File location for scenes')
     split_group.add_argument('--split_method', type=str, default='pyscene', help='Specify splitting method',
                              choices=['pyscene', 'aom_keyframes'])
@@ -99,7 +105,7 @@ def arg_parsing():
     split_group.add_argument('--min_scene_len', type=int, default=None, help='Minimum number of frames in a split')
 
     # PySceneDetect split
-    split_group.add_argument('--threshold', '-tr', type=float, default=50, help='PySceneDetect Threshold')
+    split_group.add_argument('--threshold', '-tr', type=float, default=35, help='PySceneDetect Threshold')
 
     # AOM Keyframe split
     split_group.add_argument('--reuse_first_pass', help='Reuse the first pass from aom_keyframes split on the chunks',
@@ -140,5 +146,6 @@ def arg_parsing():
     tvmaf_group.add_argument('--max_q', type=int, default=None, help='Max q for target vmaf')
     tvmaf_group.add_argument('--vmaf_plots', help='Make plots of probes in temp folder', action='store_true')
     tvmaf_group.add_argument('--vmaf_rate', type=int, default=4, help='Framerate for probes, 0 - original')
+    tvmaf_group.add_argument('--vmaf_filter', type=str, default=None, help='Filter applied to source at vmaf calcualation, use if you crop source')
 
     return Args(vars(parser.parse_args()))
