@@ -8,11 +8,9 @@ from typing import List
 from numpy import linspace
 
 from .arg_parse import Args
-from .ffmpeg import frame_probe, get_keyframes
-from .aom_kf import aom_keyframes, AOM_KEYFRAMES_DEFAULT_PARAMS
+from Scenedetection import aom_keyframes, AOM_KEYFRAMES_DEFAULT_PARAMS, pyscene
 from .logger import log
-from .pyscene import pyscene
-from .utils import terminate
+from .utils import terminate, frame_probe
 
 
 def split_routine(args: Args, resuming: bool) -> List[int]:
@@ -113,8 +111,8 @@ def extra_splits(args: Args, split_locations: list):
     for i in splits:
         distance = (i[1] - i[0])
         if distance > args.extra_split:
-            to_add = distance // args.extra_split 
-            new_scenes = list(linspace(i[0],i[1], to_add + 1, dtype=int, endpoint=False)[1:])  
+            to_add = distance // args.extra_split
+            new_scenes = list(linspace(i[0],i[1], to_add + 1, dtype=int, endpoint=False)[1:])
             split_locations.extend(new_scenes)
 
     result = [int(x) for x in sorted(split_locations)]
@@ -148,7 +146,7 @@ def calc_split_locations(args: Args) -> List[int]:
     if args.split_method == 'pyscene':
         log(f'Starting scene detection Threshold: {args.threshold}, Min_scene_length: {args.min_scene_len}\n')
         try:
-            sc = pyscene(args.input, args.threshold, args.min_scene_len)
+            sc = pyscene(args.input, args.threshold, args.min_scene_len, args.is_vs, args.temp)
         except Exception as e:
             log(f'Error in PySceneDetect: {e}\n')
             print(f'Error in PySceneDetect{e}\n')
@@ -157,7 +155,7 @@ def calc_split_locations(args: Args) -> List[int]:
     # Splitting based on aom keyframe placement
     elif args.split_method == 'aom_keyframes':
         stat_file = args.temp / 'keyframes.log'
-        sc = aom_keyframes(args.input, stat_file, args.min_scene_len, args.ffmpeg_pipe, aom_keyframes_params)
+        sc = aom_keyframes(args.input, stat_file, args.min_scene_len, args.ffmpeg_pipe, aom_keyframes_params, args.is_vs)
     else:
         print(f'No valid split option: {args.split_method}\nValid options: "pyscene", "aom_keyframes"')
         terminate()
